@@ -123,9 +123,11 @@ void KSMainWindow::init()
     QPoint location = guiConfig.readEntry("window-position", QPoint(50, 50));
     move(location);
 
-    // change window title on save
+    // change window title on save and on autosave
 
     connect(ExportManager::instance(), &ExportManager::imageSaved, this, &KSMainWindow::imageSaved);
+    connect(ExportManager::instance(), &ExportManager::imageCopied, this, &KSMainWindow::imageCopied);
+    connect(ExportManager::instance(), &ExportManager::imageSavedAndCopied, this, &KSMainWindow::imageSavedAndCopied);
 
     // the KSGWidget
 
@@ -155,7 +157,7 @@ void KSMainWindow::init()
     mSendToButton->setAutoDefault(false);
     mDialogButtonBox->addButton(mSendToButton, QDialogButtonBox::ActionRole);
 
-    mClipboardButton->setDefaultAction(KStandardAction::copy(this, SLOT(sendToClipboard()), this));
+    mClipboardButton->setDefaultAction(KStandardAction::copy(ExportManager::instance(), &ExportManager::doCopyToClipboard, this));
     mClipboardButton->setText(i18n("Copy to Clipboard"));
     mClipboardButton->setToolTip(i18n("Copy the current screenshot image to the clipboard."));
     mClipboardButton->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
@@ -224,6 +226,10 @@ void KSMainWindow::init()
     actionQuit->setShortcut(QKeySequence::Quit);
     addAction(actionQuit);
 
+    // message: open containing folder
+    mOpenContaining = new QAction(QIcon::fromTheme(QStringLiteral("document-open-folder")), i18n("Open Containing Folder"), mMessageWidget);
+    connect(mOpenContaining, &QAction::triggered, [=] { KIO::highlightInFileManager({SpectacleConfig::instance()->lastSaveFile()});});
+
     mHideMessageWidgetTimer = new QTimer(this);
     connect(mHideMessageWidgetTimer, &QTimer::timeout,
             mMessageWidget, &KMessageWidget::animatedHide);
@@ -301,6 +307,7 @@ void KSMainWindow::captureScreenshot(Spectacle::CaptureMode theCaptureMode, int
     connect(delayAnimation, &QVariantAnimation::valueChanged, this, [=] {
         const double progress = delayAnimation->currentValue().toDouble();
         const double timeoutInSeconds = theTimeout / 1000.0;
+        mKSWidget->setProgress(progress);
         unityUpdate({ {QStringLiteral("progress"), progress} });
         setWindowTitle(i18ncp("@title:window", "%1 second", "%1 seconds",
             qMin(int(timeoutInSeconds), qCeil((1 - progress) * timeoutInSeconds))));
@@ -308,6 +315,7 @@ void KSMainWindow::captureScreenshot(Spectacle::CaptureMode theCaptureMode, int
     connect(timer, &QTimer::timeout, this, [=] {
         this->hide();
         timer->deleteLater();
+        mKSWidget->setProgress(0);
         unityUpdate({ {QStringLiteral("progress-visible"), false} });
         emit newScreenshotRequest(theCaptureMode, 0, theIncludePointer, theIncludeDecorations);
     });
@@ -396,10 +404,6 @@ void KSMainWindow::quit(const QuitBehavior quitBehavior)
         // TODO: Find better solution
         QTimer::singleShot(250, qApp, &QApplication::quit);
     }
-    // TODO for else case:
-    // Currently it is expected that you emit forceNotify, and finally quit
-    // via a callback through KNotification::action1Activated. However, that
-    // is not working quite right, see Bug #389694 which needs fixing.
 }
 
 void KSMainWindow::showInlineMessage(const QString& message, const KMessageWidget::MessageType messageType,
@@ -458,11 +462,8 @@ void KSMainWindow::showImageSharedFeedback(bool error, const QString &message)
     }
 }
 
-void KSMainWindow::sendToClipboard()
+void KSMainWindow::imageCopied()
 {
-    bool notify = false;
-    ExportManager::instance()->doCopyToClipboard(notify);
-
     SpectacleConfig::instance()->quitAfterSaveOrCopyChecked()
             ? quit()
             : showInlineMessage(i18n("The screenshot has been copied to the clipboard."),
@@ -479,11 +480,18 @@ void KSMainWindow::imageSaved(const QUrl &location)
 {
     setWindowTitle(location.fileName());
     setWindowModified(false);
-    QAction* openContaining = new QAction(QIcon::fromTheme(QStringLiteral("document-open-folder")), i18n("Open Containing Folder"), mMessageWidget);
-    connect(openContaining, &QAction::triggered, [=] { KIO::highlightInFileManager({location});});
     showInlineMessage(i18n("The screenshot was saved as <a href=\"%1\">%2</a>",
                            location.toString(), location.fileName()), KMessageWidget::Positive,
-                           MessageDuration::AutoHide, {openContaining});
+                           MessageDuration::AutoHide, {mOpenContaining});
+}
+
+void KSMainWindow::imageSavedAndCopied(const QUrl &location)
+{
+    setWindowTitle(location.fileName());
+    setWindowModified(false);
+    showInlineMessage(i18n("The screenshot was copied to the clipboard and saved as <a href=\"%1\">%2</a>",
+                           location.toString(), location.fileName()), KMessageWidget::Positive,
+                           MessageDuration::AutoHide, {mOpenContaining});
 }
 
 void KSMainWindow::save()
